@@ -13,6 +13,7 @@
 #   limitations under the License.
 
 import functools as ft
+import warnings
 
 import numpy as np
 import numpy.testing as npt
@@ -437,6 +438,11 @@ class TestMatchesScipy:
             {"lam": Rplus},
             lambda value, lam: st.expon.logcdf(value, 0, 1 / lam),
         )
+        check_icdf(
+            pm.Exponential,
+            {"lam": Rplus},
+            lambda q, lam: st.expon.ppf(q, loc=0, scale=1 / lam),
+        )
 
     def test_laplace(self):
         check_logp(
@@ -890,24 +896,26 @@ class TestMatchesScipy:
         assert np.isinf(logp[2])
 
     def test_get_tau_sigma(self):
-        sigma = np.array(2)
-        npt.assert_almost_equal(get_tau_sigma(sigma=sigma), [1.0 / sigma**2, sigma])
+        # Fail on warnings
+        with warnings.catch_warnings():
+            warnings.simplefilter("error")
 
-        tau = np.array(2)
-        npt.assert_almost_equal(get_tau_sigma(tau=tau), [tau, tau**-0.5])
+            sigma = np.array(2)
+            npt.assert_almost_equal(get_tau_sigma(sigma=sigma), [1.0 / sigma**2, sigma])
 
-        tau, _ = get_tau_sigma(sigma=pt.constant(-2))
-        with pytest.raises(ParameterValueError):
-            tau.eval()
+            tau = np.array(2)
+            npt.assert_almost_equal(get_tau_sigma(tau=tau), [tau, tau**-0.5])
 
-        _, sigma = get_tau_sigma(tau=pt.constant(-2))
-        with pytest.raises(ParameterValueError):
-            sigma.eval()
+            tau, _ = get_tau_sigma(sigma=pt.constant(-2))
+            npt.assert_almost_equal(tau.eval(), -0.25)
 
-        sigma = [1, 2]
-        npt.assert_almost_equal(
-            get_tau_sigma(sigma=sigma), [1.0 / np.array(sigma) ** 2, np.array(sigma)]
-        )
+            _, sigma = get_tau_sigma(tau=pt.constant(-2))
+            npt.assert_almost_equal(sigma.eval(), -np.sqrt(1 / 2))
+
+            sigma = [1, 2]
+            npt.assert_almost_equal(
+                get_tau_sigma(sigma=sigma), [1.0 / np.array(sigma) ** 2, np.array(sigma)]
+            )
 
     @pytest.mark.parametrize(
         "value,mu,sigma,nu,logp",
@@ -1741,6 +1749,22 @@ class TestStudentT(BaseTestDistributionRandom):
     ]
 
 
+class TestHalfStudentT(BaseTestDistributionRandom):
+    def halfstudentt_rng_fn(self, df, loc, scale, size, rng):
+        return np.abs(st.t.rvs(df=df, loc=loc, scale=scale, size=size))
+
+    pymc_dist = pm.HalfStudentT
+    pymc_dist_params = {"nu": 5.0, "sigma": 2.0}
+    expected_rv_op_params = {"nu": 5.0, "sigma": 2.0}
+    reference_dist_params = {"df": 5.0, "loc": 0, "scale": 2.0}
+    reference_dist = lambda self: ft.partial(self.halfstudentt_rng_fn, rng=self.get_random_state())
+    checks_to_run = [
+        "check_pymc_params_match_rv_op",
+        "check_pymc_draws_match_reference",
+        "check_rv_size",
+    ]
+
+
 class TestMoyal(BaseTestDistributionRandom):
     pymc_dist = pm.Moyal
     pymc_dist_params = {"mu": 0.0, "sigma": 1.0}
