@@ -36,7 +36,7 @@
 
 import numpy as np
 import pytensor
-import pytensor.tensor as at
+import pytensor.tensor as pt
 import scipy.stats as st
 
 from pymc.logprob.censoring import MeasurableClip
@@ -46,13 +46,13 @@ from tests.logprob.utils import joint_logprob
 
 
 def test_scalar_clipped_mixture():
-    x = at.clip(at.random.normal(loc=1), 0.5, 1.5)
+    x = pt.clip(pt.random.normal(loc=1), 0.5, 1.5)
     x.name = "x"
-    y = at.random.beta(1, 2, name="y")
+    y = pt.random.beta(1, 2, name="y")
 
-    comps = at.stack([x, y])
+    comps = pt.stack([x, y])
     comps.name = "comps"
-    idxs = at.random.bernoulli(0.4, name="idxs")
+    idxs = pt.random.bernoulli(0.4, name="idxs")
     mix = comps[idxs]
     mix.name = "mix"
 
@@ -71,25 +71,25 @@ def test_scalar_clipped_mixture():
 
 
 def test_nested_scalar_mixtures():
-    x = at.random.normal(loc=-50, name="x")
-    y = at.random.normal(loc=50, name="y")
-    comps1 = at.stack([x, y])
+    x = pt.random.normal(loc=-50, name="x")
+    y = pt.random.normal(loc=50, name="y")
+    comps1 = pt.stack([x, y])
     comps1.name = "comps1"
-    idxs1 = at.random.bernoulli(0.5, name="idxs1")
+    idxs1 = pt.random.bernoulli(0.5, name="idxs1")
     mix1 = comps1[idxs1]
     mix1.name = "mix1"
 
-    w = at.random.normal(loc=-100, name="w")
-    z = at.random.normal(loc=100, name="z")
-    comps2 = at.stack([w, z])
+    w = pt.random.normal(loc=-100, name="w")
+    z = pt.random.normal(loc=100, name="z")
+    comps2 = pt.stack([w, z])
     comps2.name = "comps2"
-    idxs2 = at.random.bernoulli(0.5, name="idxs2")
+    idxs2 = pt.random.bernoulli(0.5, name="idxs2")
     mix2 = comps2[idxs2]
     mix2.name = "mix2"
 
-    comps12 = at.stack([mix1, mix2])
+    comps12 = pt.stack([mix1, mix2])
     comps12.name = "comps12"
-    idxs12 = at.random.bernoulli(0.5, name="idxs12")
+    idxs12 = pt.random.bernoulli(0.5, name="idxs12")
     mix12 = comps12[idxs12]
     mix12.name = "mix12"
 
@@ -117,9 +117,9 @@ def test_nested_scalar_mixtures():
 
 def test_unvalued_ir_reversion():
     """Make sure that un-valued IR rewrites are reverted."""
-    x_rv = at.random.normal()
-    y_rv = at.clip(x_rv, 0, 1)
-    z_rv = at.random.normal(y_rv, 1, name="z")
+    x_rv = pt.random.normal()
+    y_rv = pt.clip(x_rv, 0, 1)
+    z_rv = pt.random.normal(y_rv, 1, name="z")
     z_vv = z_rv.clone()
 
     # Only the `z_rv` is "valued", so `y_rv` doesn't need to be converted into
@@ -139,8 +139,8 @@ def test_unvalued_ir_reversion():
 
 
 def test_shifted_cumsum():
-    x = at.random.normal(size=(5,), name="x")
-    y = 5 + at.cumsum(x)
+    x = pt.random.normal(size=(5,), name="x")
+    y = 5 + pt.cumsum(x)
     y.name = "y"
 
     y_vv = y.clone()
@@ -152,8 +152,8 @@ def test_shifted_cumsum():
 
 
 def test_double_log_transform_rv():
-    base_rv = at.random.normal(0, 1)
-    y_rv = at.log(at.log(base_rv))
+    base_rv = pt.random.normal(0, 1)
+    y_rv = pt.log(pt.log(base_rv))
     y_rv.name = "y"
 
     y_vv = y_rv.clone()
@@ -170,11 +170,11 @@ def test_double_log_transform_rv():
 
 
 def test_affine_transform_rv():
-    loc = at.scalar("loc")
-    scale = at.vector("scale")
+    loc = pt.scalar("loc")
+    scale = pt.vector("scale")
     rv_size = 3
 
-    y_rv = loc + at.random.normal(0, 1, size=rv_size, name="base_rv") * scale
+    y_rv = loc + pt.random.normal(0, 1, size=rv_size, name="base_rv") * scale
     y_rv.name = "y"
     y_vv = y_rv.clone()
 
@@ -193,9 +193,9 @@ def test_affine_transform_rv():
 
 
 def test_affine_log_transform_rv():
-    a, b = at.scalars("a", "b")
-    base_rv = at.random.lognormal(0, 1, name="base_rv", size=(1, 2))
-    y_rv = a + at.log(base_rv) * b
+    a, b = pt.scalars("a", "b")
+    base_rv = pt.random.lognormal(0, 1, name="base_rv", size=(1, 2))
+    y_rv = a + pt.log(base_rv) * b
     y_rv.name = "y"
 
     y_vv = y_rv.clone()
